Introduction
============


.. image:: https://readthedocs.org/projects/adafruit-circuitpython-asyncio/badge/?version=latest
    :target: https://docs.circuitpython.org/projects/asyncio/en/latest/
    :alt: Documentation Status


.. image:: https://raw.githubusercontent.com/adafruit/Adafruit_CircuitPython_Bundle/main/badges/adafruit_discord.svg
    :target: https://adafru.it/discord
    :alt: Discord


.. image:: https://github.com/adafruit/Adafruit_CircuitPython_asyncio/workflows/Build%20CI/badge.svg
    :target: https://github.com/adafruit/Adafruit_CircuitPython_asyncio/actions
    :alt: Build Status


.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Code Style: Black

Cooperative multitasking and asynchronous I/O

The code in this library is largely based on the
`MicroPython uasyncio implementation <https://github.com/micropython/micropython/tree/master/extmod/uasyncio>`_.

Dependencies
=============
This driver depends on:

* `Adafruit CircuitPython <https://github.com/adafruit/circuitpython>`_

Please ensure all dependencies are available on the CircuitPython filesystem.
This is easily achieved by downloading
`the Adafruit library and driver bundle <https://circuitpython.org/libraries>`_
or individual libraries can be installed using
`circup <https://github.com/adafruit/circup>`_.


Installing from PyPI
=====================
This library is meant to be a subset of the ` ``asyncio`` module in CPython
<https://docs.python.org/3/library/asyncio.html>`_, and will not be made available on PyPI.
Use the CPython version instead.


Installing to a Connected CircuitPython Device with Circup
==========================================================

Make sure that you have ``circup`` installed in your Python environment.
Install it with the following command if necessary:

.. code-block:: shell

    pip3 install circup

With ``circup`` installed and your CircuitPython device connected use the
following command to install:

.. code-block:: shell

    circup install asyncio

Or the following command to update an existing version:

.. code-block:: shell

    circup update

Documentation
=============

API documentation for this library can be found on `Read the Docs <https://circuitpython.readthedocs.io/en/latest/docs/library/asyncio.html>`_.

For information on building library documentation, please check out
`this guide <https://learn.adafruit.com/creating-and-sharing-a-circuitpython-library/sharing-our-docs-on-readthedocs#sphinx-5-1>`_.

Contributing
============

Contributions are welcome! Please read our `Code of Conduct
<https://github.com/adafruit/Adafruit_CircuitPython_asyncio/blob/HEAD/CODE_OF_CONDUCT.md>`_
before contributing to help this project stay welcoming.
